@@ -21,7 +21,7 @@ seconds_in_hour = 3600
 seconds_in_half_hour = 1800
 fillvalue_double = 9.969209968386869e+36
 fillvalue_float = 9.96921e+36
-jaws_version = '0.8.2'
+jaws_version = '0.8.3'
 
 ###############################################################################
 
@@ -114,7 +114,7 @@ def load_dataframe(name, input_file, header_rows, **kwargs):
 
 
 def load_dataset_attributes(name, ds, args, **kwargs):
-    global derived_vars, no_drv_tm_vars, rigb_vars
+    global derived_vars, no_drv_tm_vars, rigb_vars, flx_vars
     path = 'resources/{}/ds.json'.format(name)
     attr_dict = read_ordered_json(path)
 
@@ -146,9 +146,14 @@ def load_dataset_attributes(name, ds, args, **kwargs):
     if name in ['imau/ant', 'imau/grl', 'gcnet', 'promice']:
         rigb_vars = kwargs.pop('rigb_vars')
 
+    flx_vars = []
+    if name == 'gcnet' and args.flx:
+        flx_vars = ['sh', 'lh']
+
     for key, value in attr_dict.items():
         for key1, value1 in value.items():
-            if (key1 in columns) or (key1 in derived_vars) or (key1 in no_drv_tm_vars) or (key1 in rigb_vars):
+            if (key1 in columns) or (key1 in derived_vars) or (key1 in no_drv_tm_vars) or (
+                    key1 in rigb_vars) or (key1 in flx_vars):
                 for key2, value2 in value1.items():
                     if key2 == 'type':
                         pass
@@ -199,6 +204,8 @@ def get_encoding(name, fillvalue, comp_level, args):
         masterlist.append(no_drv_tm_vars)
     if args.rigb:
         masterlist.append(rigb_vars)
+    if args.flx:
+        masterlist.append(flx_vars)
 
     # Get encoding for only those variables present in input file
     masterlist = [item for sublist in masterlist for item in sublist]
